@@ -149,34 +149,34 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
             closest_time, reverse = find_prev_closest_time(prompt_time, subset_time_series)
 
-            if get_min_diff(prompt_time, closest_time) < 5:
-                phone_event = list(df_logs_combined[df_logs_combined['EVENT_TIME_DATETIME'] == closest_time][
-                                         "APP_EVENT"])[0]
+            # if get_min_diff(prompt_time, closest_time) < 5:
+            phone_event = list(df_logs_combined[df_logs_combined['EVENT_TIME_DATETIME'] == closest_time][
+                                     "APP_EVENT"])[0]
 
-                # to determine phone on/off
-                if not reverse:
-                    if phone_event == "KEYGUARD_HIDDEN":
-                        phone_lock = "Phone Unlocked"
-                        last_usage = 0
-                    elif phone_event == "KEYGUARD_SHOWN":
-                        phone_lock = "Phone Locked"
-                        last_usage = calculate_duration(prompt_time, closest_time)
-                    else:
-                        phone_lock = "NF"
-                        last_usage = "NF"
+            # to determine phone on/off
+            if not reverse:
+                if phone_event == "KEYGUARD_HIDDEN":
+                    phone_lock = "Phone Unlocked"
+                    last_usage = 0
+                elif phone_event == "KEYGUARD_SHOWN":
+                    phone_lock = "Phone Locked"
+                    last_usage = calculate_duration(prompt_time, closest_time)
                 else:
-                    if phone_event == "KEYGUARD_HIDDEN":
-                        phone_lock = "Phone Locked"
-                        last_usage = "NF"
-                    elif phone_event == "KEYGUARD_SHOWN":
-                        phone_lock = "Phone Unlocked"
-                        last_usage = 0
-                    else:
-                        phone_lock = "NF"
-                        last_usage = "NF"
+                    phone_lock = "NF"
+                    last_usage = "NF"
             else:
-                phone_lock = "NF"
-                last_usage = "NF"
+                if phone_event == "KEYGUARD_HIDDEN":
+                    phone_lock = "Phone Locked"
+                    last_usage = "NF"
+                elif phone_event == "KEYGUARD_SHOWN":
+                    phone_lock = "Phone Unlocked"
+                    last_usage = 0
+                else:
+                    phone_lock = "NF"
+                    last_usage = "NF"
+            # else:
+            #     phone_lock = "NF"
+            #     last_usage = "NF"
 
             # print("==   {}".format(phone_lock))
 
